@@ -1,6 +1,12 @@
 package MooseX::amine;
+BEGIN {
+  $MooseX::amine::VERSION = '0.1';
+}
+BEGIN {
+  $MooseX::amine::AUTHORITY = 'cpan:GENEHACK';
+}
 # ABSTRACT: Examine Yr Moose
-$MooseX::amine::VERSION = '0.07';
+
 use Moose;
 use Moose::Meta::Class;
 use Moose::Meta::Role;
@@ -76,7 +82,7 @@ has '_metaobj' => (
 sub _build_metaobj {
   my $self = shift;
   return $self->{module}->meta
-    || die "Can't get meta object for module!" ;
+    or die "Can't get meta object for module!" ;
 }
 
 has '_methods' => (
@@ -202,13 +208,12 @@ sub _dissect_attribute {
   my $meta_attr = $meta->get_attribute( $attribute_name );
 
   my $return;
-  my $ref = ref $meta_attr;
-  if ( $ref eq 'Moose::Meta::Role::Attribute' ) {
-    $return = $meta_attr->original_role->name;
-    $meta_attr = $meta_attr->attribute_for_class();
-  }
-  else {
-    $return = $meta_attr->associated_class->name
+  given ( ref $meta_attr ) {
+    when( 'Moose::Meta::Role::Attribute' ) {
+      $return = $meta_attr->original_role->name;
+      $meta_attr = $meta_attr->attribute_for_class();
+    }
+    default { $return = $meta_attr->associated_class->name }
   }
 
   my $extracted_attribute = $self->_extract_attribute_metainfo( $meta_attr );
@@ -255,9 +260,7 @@ sub _dissect_method {
 
   unless ( $self->include_standard_methods ) {
     my @STOCK = qw/ DESTROY meta new /;
-    foreach ( @STOCK ) {
-      return if $method_name eq $_;
-    }
+    return if $method_name ~~ @STOCK;
   }
 
   my $extracted_method =  $self->_extract_method_metainfo( $meta_method );
@@ -273,7 +276,6 @@ sub _dissect_role {
 
   my @names = split '\|' , $meta->name;
   foreach my $name ( @names ) {
-    next if $name =~ /Moose::Meta::Role::__ANON/;
     $self->_extract_sub_nodes( $name );
   }
 }
@@ -297,9 +299,6 @@ sub _extract_attribute_metainfo {
   $return->{meta}{constraint} = $meta_attr->type_constraint->name
     if ( $meta_attr->has_type_constraint );
 
-  $return->{meta}{traits} = $meta_attr->applied_traits
-    if ( $meta_attr->has_applied_traits );
-
   foreach ( qw/
                 is_weak_ref is_required is_lazy is_lazy_build should_coerce
                 should_auto_deref has_trigger has_handles
@@ -329,25 +328,21 @@ sub _extract_sub_nodes {
 
   my $path = $name . '.pm';
   $path =~ s|::|/|g;
-  if ( $path = $INC{$path} ){
-    try {
-      my $ppi = PPI::Document->new( $path )
-        or die "Can't load PPI for $path ($!)";
+  $path = $INC{$path};
 
-      my $sub_nodes = $ppi->find(
-        sub{ $_[1]->isa( 'PPI::Statement::Sub' ) && $_[1]->name }
-      );
+  my $ppi = PPI::Document->new( $path )
+    or die "Can't load PPI for $path ($!)";
 
-      foreach my $sub_node ( @$sub_nodes ) {
-        my $name = $sub_node->name;
-        $self->_store_sub_node( $name => $sub_node->content );
-      }
-    };
-    # FIXME should probably do something about errors here...
+  my $sub_nodes = $ppi->find(
+    sub{ $_[1]->isa( 'PPI::Statement::Sub' ) && $_[1]->name }
+  );
+
+  foreach my $sub_node ( @$sub_nodes ) {
+    my $name = $sub_node->name;
+    $self->_store_sub_node( $name => $sub_node->content );
   }
 }
 
-
 # given a module name and a path to that module, dynamically load the
 # module. figures out the appropriate 'use lib' statement based on the path.
 sub _load_module_from_path {
@@ -372,23 +367,20 @@ sub _load_module_from_path {
   return $module;
 }
 
-
 #__PACKAGE__->meta->make_immutable;
 1;
 
+
 __END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 MooseX::amine - Examine Yr Moose
 
 =head1 VERSION
 
-version 0.07
+version 0.1
 
 =head1 SYNOPSIS
 
@@ -460,25 +452,16 @@ The C<code> key will contain the actual code from the method, extracted with
 PPI. Depending on where the method code actually lives, this key may or may
 not be present.
 
-=head1 CREDITS
-
-=over 4
-
-=item Semi-inspired by L<MooseX::Documenter>.
-
-=item Syntax highlighting Javascript/CSS stuff based on SHJS and largely stolen from search.cpan.org.
-
-=back
-
 =head1 AUTHOR
 
-John SJ Anderson <john@genehack.org>
+John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by John SJ Anderson.
+This software is copyright (c) 2011 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
